==> openshift-model-5.9.0-sources.jar: io/fabric8/openshift/api/model/PodSecurityPolicySubjectReviewFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
public class PodSecurityPolicySubjectReviewFluentImpl<A extends io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluent<A>{
  public PodSecurityPolicySubjectReviewFluentImpl() {
  }
  public PodSecurityPolicySubjectReviewFluentImpl(io.fabric8.openshift.api.model.PodSecurityPolicySubjectReview instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
  }
  private java.lang.String apiVersion;
  private java.lang.String kind;
  private io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpecBuilder spec;
  private io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewStatusBuilder status;
  public java.lang.String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(java.lang.String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public java.lang.Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  
  /**
   * Method is deprecated. use withApiVersion instead.
   */
  @java.lang.Deprecated
  public A withNewApiVersion(java.lang.String arg0) {
    return (A)withApiVersion(new String(arg0));
  }
  public java.lang.String getKind() {
    return this.kind;
  }
  public A withKind(java.lang.String kind) {
    this.kind=kind; return (A) this;
  }
  public java.lang.Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * Method is deprecated. use withKind instead.
   */
  @java.lang.Deprecated
  public A withNewKind(java.lang.String arg0) {
    return (A)withKind(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpec getSpec() {
    return this.spec!=null?this.spec.build():null;
  }
  public io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpec buildSpec() {
    return this.spec!=null?this.spec.build():null;
  }
  public A withSpec(io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpecBuilder(spec); _visitables.get("spec").add(this.spec);} return (A) this;
  }
  public java.lang.Boolean hasSpec() {
    return this.spec != null;
  }
  public io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluent.SpecNested<A> withNewSpec() {
    return new io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluentImpl.SpecNestedImpl();
  }
  public io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluent.SpecNested<A> withNewSpecLike(io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpec item) {
    return new io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluentImpl.SpecNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpecBuilder().build());
  }
  public io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluent.SpecNested<A> editOrNewSpecLike(io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewStatus getStatus() {
    return this.status!=null?this.status.build():null;
  }
  public io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewStatus buildStatus() {
    return this.status!=null?this.status.build():null;
  }
  public A withStatus(io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewStatusBuilder(status); _visitables.get("status").add(this.status);} return (A) this;
  }
  public java.lang.Boolean hasStatus() {
    return this.status != null;
  }
  public io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluent.StatusNested<A> withNewStatus() {
    return new io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluentImpl.StatusNestedImpl();
  }
  public io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluent.StatusNested<A> withNewStatusLike(io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewStatus item) {
    return new io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluentImpl.StatusNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewStatusBuilder().build());
  }
  public io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluent.StatusNested<A> editOrNewStatusLike(io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    PodSecurityPolicySubjectReviewFluentImpl that = (PodSecurityPolicySubjectReviewFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  spec,  status,  super.hashCode());
  }
  public class SpecNestedImpl<N> extends io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpecFluentImpl<io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluent.SpecNested<N>> implements io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluent.SpecNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    SpecNestedImpl(io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpec item) {
      this.builder = new io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpecBuilder(this);
    }
    io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpecBuilder builder;
    public N and() {
      return (N) PodSecurityPolicySubjectReviewFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  public class StatusNestedImpl<N> extends io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewStatusFluentImpl<io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluent.StatusNested<N>> implements io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluent.StatusNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    StatusNestedImpl(io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewStatus item) {
      this.builder = new io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewStatusBuilder(this);
    }
    io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewStatusBuilder builder;
    public N and() {
      return (N) PodSecurityPolicySubjectReviewFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/PodSecurityPolicySubjectReviewFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class PodSecurityPolicySubjectReviewFluentImpl<A extends io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluent<A>{
  public PodSecurityPolicySubjectReviewFluentImpl() {
  }
  public PodSecurityPolicySubjectReviewFluentImpl(io.fabric8.openshift.api.model.PodSecurityPolicySubjectReview instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String apiVersion;
  private java.lang.String kind;
  private io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpecBuilder spec;
  private io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewStatusBuilder status;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(java.lang.String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public java.lang.Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  
  /**
   * Method is deprecated. use withApiVersion instead.
   */
  @java.lang.Deprecated
  public A withNewApiVersion(java.lang.String arg0) {
    return (A)withApiVersion(new String(arg0));
  }
  public java.lang.String getKind() {
    return this.kind;
  }
  public A withKind(java.lang.String kind) {
    this.kind=kind; return (A) this;
  }
  public java.lang.Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * Method is deprecated. use withKind instead.
   */
  @java.lang.Deprecated
  public A withNewKind(java.lang.String arg0) {
    return (A)withKind(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpec getSpec() {
    return this.spec!=null?this.spec.build():null;
  }
  public io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpec buildSpec() {
    return this.spec!=null?this.spec.build():null;
  }
  public A withSpec(io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpecBuilder(spec); _visitables.get("spec").add(this.spec);} return (A) this;
  }
  public java.lang.Boolean hasSpec() {
    return this.spec != null;
  }
  public io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluent.SpecNested<A> withNewSpec() {
    return new io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluentImpl.SpecNestedImpl();
  }
  public io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluent.SpecNested<A> withNewSpecLike(io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpec item) {
    return new io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluentImpl.SpecNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpecBuilder().build());
  }
  public io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluent.SpecNested<A> editOrNewSpecLike(io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewStatus getStatus() {
    return this.status!=null?this.status.build():null;
  }
  public io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewStatus buildStatus() {
    return this.status!=null?this.status.build():null;
  }
  public A withStatus(io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewStatusBuilder(status); _visitables.get("status").add(this.status);} return (A) this;
  }
  public java.lang.Boolean hasStatus() {
    return this.status != null;
  }
  public io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluent.StatusNested<A> withNewStatus() {
    return new io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluentImpl.StatusNestedImpl();
  }
  public io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluent.StatusNested<A> withNewStatusLike(io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewStatus item) {
    return new io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluentImpl.StatusNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewStatusBuilder().build());
  }
  public io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluent.StatusNested<A> editOrNewStatusLike(io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    PodSecurityPolicySubjectReviewFluentImpl that = (PodSecurityPolicySubjectReviewFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  spec,  status,  additionalProperties,  super.hashCode());
  }
  public class SpecNestedImpl<N> extends io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpecFluentImpl<io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluent.SpecNested<N>> implements io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluent.SpecNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    SpecNestedImpl(io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpec item) {
      this.builder = new io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpecBuilder(this);
    }
    io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewSpecBuilder builder;
    public N and() {
      return (N) PodSecurityPolicySubjectReviewFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  public class StatusNestedImpl<N> extends io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewStatusFluentImpl<io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluent.StatusNested<N>> implements io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewFluent.StatusNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    StatusNestedImpl(io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewStatus item) {
      this.builder = new io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewStatusBuilder(this);
    }
    io.fabric8.openshift.api.model.PodSecurityPolicySubjectReviewStatusBuilder builder;
    public N and() {
      return (N) PodSecurityPolicySubjectReviewFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}
